# openapi.api.DefaultApi

## Load the API package
```dart
import 'package:openapi/api.dart';
```

All URIs are relative to *https://onesignal.com/api/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**cancelNotification**](DefaultApi.md#cancelnotification) | **DELETE** /notifications/{notification_id} | Stop a scheduled or currently outgoing notification
[**createApp**](DefaultApi.md#createapp) | **POST** /apps | Create an app
[**createNotification**](DefaultApi.md#createnotification) | **POST** /notifications | Create notification
[**createPlayer**](DefaultApi.md#createplayer) | **POST** /players | Add a device
[**createSegments**](DefaultApi.md#createsegments) | **POST** /apps/{app_id}/segments | Create Segments
[**deletePlayer**](DefaultApi.md#deleteplayer) | **DELETE** /players/{player_id} | Delete a user record
[**deleteSegments**](DefaultApi.md#deletesegments) | **DELETE** /apps/{app_id}/segments/{segment_id} | Delete Segments
[**exportPlayers**](DefaultApi.md#exportplayers) | **POST** /players/csv_export?app_id={app_id} | CSV export
[**getApp**](DefaultApi.md#getapp) | **GET** /apps/{app_id} | View an app
[**getApps**](DefaultApi.md#getapps) | **GET** /apps | View apps
[**getNotification**](DefaultApi.md#getnotification) | **GET** /notifications/{notification_id} | View notification
[**getNotificationHistory**](DefaultApi.md#getnotificationhistory) | **POST** /notifications/{notification_id}/history | Notification History
[**getNotifications**](DefaultApi.md#getnotifications) | **GET** /notifications | View notifications
[**getOutcomes**](DefaultApi.md#getoutcomes) | **GET** /apps/{app_id}/outcomes | View Outcomes
[**getPlayer**](DefaultApi.md#getplayer) | **GET** /players/{player_id} | View device
[**getPlayers**](DefaultApi.md#getplayers) | **GET** /players | View devices
[**updateApp**](DefaultApi.md#updateapp) | **PUT** /apps/{app_id} | Update an app
[**updatePlayer**](DefaultApi.md#updateplayer) | **PUT** /players/{player_id} | Edit device
[**updatePlayerTags**](DefaultApi.md#updateplayertags) | **PUT** /apps/{app_id}/users/{external_user_id} | Edit tags with external user id


# **cancelNotification**
> CancelNotificationSuccessResponse cancelNotification(appId, notificationId)

Stop a scheduled or currently outgoing notification

Used to stop a scheduled or currently outgoing notification

### Example
```dart
import 'package:openapi/api.dart';
// TODO Configure HTTP Bearer authorization: app_key
// Case 1. Use String Token
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken('YOUR_ACCESS_TOKEN');
// Case 2. Use Function which generate token.
// String yourTokenGeneratorFunction() { ... }
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken(yourTokenGeneratorFunction);

final api_instance = DefaultApi();
final appId = appId_example; // String | 
final notificationId = notificationId_example; // String | 

try {
    final result = api_instance.cancelNotification(appId, notificationId);
    print(result);
} catch (e) {
    print('Exception when calling DefaultApi->cancelNotification: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **appId** | **String**|  | 
 **notificationId** | **String**|  | 

### Return type

[**CancelNotificationSuccessResponse**](CancelNotificationSuccessResponse.md)

### Authorization

[app_key](../README.md#app_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **createApp**
> App createApp(app)

Create an app

Creates a new OneSignal app

### Example
```dart
import 'package:openapi/api.dart';
// TODO Configure HTTP Bearer authorization: user_key
// Case 1. Use String Token
//defaultApiClient.getAuthentication<HttpBearerAuth>('user_key').setAccessToken('YOUR_ACCESS_TOKEN');
// Case 2. Use Function which generate token.
// String yourTokenGeneratorFunction() { ... }
//defaultApiClient.getAuthentication<HttpBearerAuth>('user_key').setAccessToken(yourTokenGeneratorFunction);

final api_instance = DefaultApi();
final app = App(); // App | 

try {
    final result = api_instance.createApp(app);
    print(result);
} catch (e) {
    print('Exception when calling DefaultApi->createApp: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **app** | [**App**](App.md)|  | 

### Return type

[**App**](App.md)

### Authorization

[user_key](../README.md#user_key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **createNotification**
> CreateNotificationSuccessResponse createNotification(notification)

Create notification

Sends notifications to your users 

### Example
```dart
import 'package:openapi/api.dart';
// TODO Configure HTTP Bearer authorization: app_key
// Case 1. Use String Token
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken('YOUR_ACCESS_TOKEN');
// Case 2. Use Function which generate token.
// String yourTokenGeneratorFunction() { ... }
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken(yourTokenGeneratorFunction);

final api_instance = DefaultApi();
final notification = Notification(); // Notification | 

try {
    final result = api_instance.createNotification(notification);
    print(result);
} catch (e) {
    print('Exception when calling DefaultApi->createNotification: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **notification** | [**Notification**](Notification.md)|  | 

### Return type

[**CreateNotificationSuccessResponse**](CreateNotificationSuccessResponse.md)

### Authorization

[app_key](../README.md#app_key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **createPlayer**
> CreatePlayerSuccessResponse createPlayer(player)

Add a device

Register a new device to one of your OneSignal apps &#x1F6A7; Don't use this This API endpoint is designed to be used from our open source Mobile and Web Push SDKs. It is not designed for developers to use it directly, unless instructed to do so by OneSignal support. If you use this method instead of our SDKs, many OneSignal features such as conversion tracking, timezone tracking, language detection, and rich-push won't work out of the box. It will also make it harder to identify possible setup issues. This method is used to register a new device with OneSignal. If a device is already registered with the specified identifier, then this will update the existing device record instead of creating a new one. The returned player is a player / user ID. Use the returned ID to send push notifications to this specific user later, or to include this player when sending to a set of users. &#x1F6A7; iOS Must set test_type to 1 when building your iOS app as development. Omit this field in your production app builds. 

### Example
```dart
import 'package:openapi/api.dart';
// TODO Configure HTTP Bearer authorization: app_key
// Case 1. Use String Token
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken('YOUR_ACCESS_TOKEN');
// Case 2. Use Function which generate token.
// String yourTokenGeneratorFunction() { ... }
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken(yourTokenGeneratorFunction);

final api_instance = DefaultApi();
final player = Player(); // Player | 

try {
    final result = api_instance.createPlayer(player);
    print(result);
} catch (e) {
    print('Exception when calling DefaultApi->createPlayer: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **player** | [**Player**](Player.md)|  | 

### Return type

[**CreatePlayerSuccessResponse**](CreatePlayerSuccessResponse.md)

### Authorization

[app_key](../README.md#app_key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **createSegments**
> CreateSegmentSuccessResponse createSegments(appId, segment)

Create Segments

Create segments visible and usable in the dashboard and API - Required: OneSignal Paid Plan The Create Segment method is used when you want your server to programmatically create a segment instead of using the OneSignal Dashboard UI. Just like creating Segments from the dashboard you can pass in filters with multiple \"AND\" or \"OR\" operator's. &#x1F6A7; Does Not Update Segments This endpoint will only create segments, it does not edit or update currently created Segments. You will need to use the Delete Segments endpoint and re-create it with this endpoint to edit. 

### Example
```dart
import 'package:openapi/api.dart';
// TODO Configure HTTP Bearer authorization: app_key
// Case 1. Use String Token
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken('YOUR_ACCESS_TOKEN');
// Case 2. Use Function which generate token.
// String yourTokenGeneratorFunction() { ... }
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken(yourTokenGeneratorFunction);

final api_instance = DefaultApi();
final appId = appId_example; // String | The OneSignal App ID for your app.  Available in Keys & IDs.
final segment = Segment(); // Segment | 

try {
    final result = api_instance.createSegments(appId, segment);
    print(result);
} catch (e) {
    print('Exception when calling DefaultApi->createSegments: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **appId** | **String**| The OneSignal App ID for your app.  Available in Keys & IDs. | 
 **segment** | [**Segment**](Segment.md)|  | [optional] 

### Return type

[**CreateSegmentSuccessResponse**](CreateSegmentSuccessResponse.md)

### Authorization

[app_key](../README.md#app_key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deletePlayer**
> DeletePlayerSuccessResponse deletePlayer(appId, playerId)

Delete a user record

Delete player - Required: Used to delete a single, specific Player ID record from a specific OneSignal app. 

### Example
```dart
import 'package:openapi/api.dart';
// TODO Configure HTTP Bearer authorization: app_key
// Case 1. Use String Token
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken('YOUR_ACCESS_TOKEN');
// Case 2. Use Function which generate token.
// String yourTokenGeneratorFunction() { ... }
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken(yourTokenGeneratorFunction);

final api_instance = DefaultApi();
final appId = appId_example; // String | The OneSignal App ID for your app.  Available in Keys & IDs.
final playerId = playerId_example; // String | The OneSignal player_id

try {
    final result = api_instance.deletePlayer(appId, playerId);
    print(result);
} catch (e) {
    print('Exception when calling DefaultApi->deletePlayer: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **appId** | **String**| The OneSignal App ID for your app.  Available in Keys & IDs. | 
 **playerId** | **String**| The OneSignal player_id | 

### Return type

[**DeletePlayerSuccessResponse**](DeletePlayerSuccessResponse.md)

### Authorization

[app_key](../README.md#app_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteSegments**
> DeleteSegmentSuccessResponse deleteSegments(appId, segmentId)

Delete Segments

Delete segments (not user devices) - Required: OneSignal Paid Plan You can delete a segment under your app by calling this API. You must provide an API key in the Authorization header that has admin access on the app. The segment_id can be found in the URL of the segment when viewing it in the dashboard. 

### Example
```dart
import 'package:openapi/api.dart';
// TODO Configure HTTP Bearer authorization: app_key
// Case 1. Use String Token
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken('YOUR_ACCESS_TOKEN');
// Case 2. Use Function which generate token.
// String yourTokenGeneratorFunction() { ... }
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken(yourTokenGeneratorFunction);

final api_instance = DefaultApi();
final appId = appId_example; // String | The OneSignal App ID for your app.  Available in Keys & IDs.
final segmentId = segmentId_example; // String | The segment_id can be found in the URL of the segment when viewing it in the dashboard.

try {
    final result = api_instance.deleteSegments(appId, segmentId);
    print(result);
} catch (e) {
    print('Exception when calling DefaultApi->deleteSegments: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **appId** | **String**| The OneSignal App ID for your app.  Available in Keys & IDs. | 
 **segmentId** | **String**| The segment_id can be found in the URL of the segment when viewing it in the dashboard. | 

### Return type

[**DeleteSegmentSuccessResponse**](DeleteSegmentSuccessResponse.md)

### Authorization

[app_key](../README.md#app_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **exportPlayers**
> ExportPlayersSuccessResponse exportPlayers(appId, exportPlayersRequestBody)

CSV export

Generate a compressed CSV export of all of your current user data This method can be used to generate a compressed CSV export of all of your current user data. It is a much faster alternative than retrieving this data using the /players API endpoint. The file will be compressed using GZip. The file may take several minutes to generate depending on the number of users in your app. The URL generated will be available for 3 days and includes random v4 uuid as part of the resource name to be unguessable. &#x1F6A7; 403 Error Responses          You can test if it is complete by making a GET request to the csv_file_url value. This file may take time to generate depending on how many device records are being pulled. If the file is not ready, a 403 error will be returned. Otherwise the file itself will be returned. &#x1F6A7; Requires Authentication Key Requires your OneSignal App's REST API Key, available in Keys & IDs. &#x1F6A7; Concurrent Exports Only one concurrent export is allowed per OneSignal account. Please ensure you have successfully downloaded the .csv.gz file before exporting another app. CSV File Format: - Default Columns:   | Field | Details |   | --- | --- |   | id | OneSignal Player Id |   | identifier | Push Token |   | session_count | Number of times they visited the app or site   | language | Device language code |   | timezone | Number of seconds away from UTC. Example: -28800 |   | game_version | Version of your mobile app gathered from Android Studio versionCode in your App/build.gradle and iOS uses kCFBundleVersionKey in Xcode. |   | device_os | Device Operating System Version. Example: 80 = Chrome 80, 9 = Android 9 |   | device_type | Device Operating System Type |   | device_model | Device Hardware String Code. Example: Mobile Web Subscribers will have `Linux armv` |   | ad_id | Based on the Google Advertising Id for Android, identifierForVendor for iOS. OptedOut means user turned off Advertising tracking on the device. |   | tags | Current OneSignal Data Tags on the device. |   | last_active | Date and time the user last opened the mobile app or visited the site. |   | playtime | Total amount of time in seconds the user had the mobile app open. |   | amount_spent |  Mobile only - amount spent in USD on In-App Purchases. |    | created_at | Date and time the device record was created in OneSignal. Mobile - first time they opened the app with OneSignal SDK. Web - first time the user subscribed to the site. |   | invalid_identifier | t = unsubscribed, f = subscibed |   | badge_count | Current number of badges on the device | - Extra Columns:   | Field | Details |   | --- | --- |   | external_user_id | Your User Id set on the device |   | notification_types | Notification types |   | location | Location points (Latitude and Longitude) set on the device. |   | country | Country code |   | rooted | Android device rooted or not |   | ip | IP Address of the device if being tracked. See Handling Personal Data. |   | web_auth | Web Only authorization key. |   | web_p256 | Web Only p256 key. | 

### Example
```dart
import 'package:openapi/api.dart';
// TODO Configure HTTP Bearer authorization: app_key
// Case 1. Use String Token
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken('YOUR_ACCESS_TOKEN');
// Case 2. Use Function which generate token.
// String yourTokenGeneratorFunction() { ... }
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken(yourTokenGeneratorFunction);

final api_instance = DefaultApi();
final appId = appId_example; // String | The app ID that you want to export devices from
final exportPlayersRequestBody = ExportPlayersRequestBody(); // ExportPlayersRequestBody | 

try {
    final result = api_instance.exportPlayers(appId, exportPlayersRequestBody);
    print(result);
} catch (e) {
    print('Exception when calling DefaultApi->exportPlayers: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **appId** | **String**| The app ID that you want to export devices from | 
 **exportPlayersRequestBody** | [**ExportPlayersRequestBody**](ExportPlayersRequestBody.md)|  | [optional] 

### Return type

[**ExportPlayersSuccessResponse**](ExportPlayersSuccessResponse.md)

### Authorization

[app_key](../README.md#app_key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getApp**
> App getApp(appId)

View an app

View the details of a single OneSignal app

### Example
```dart
import 'package:openapi/api.dart';
// TODO Configure HTTP Bearer authorization: user_key
// Case 1. Use String Token
//defaultApiClient.getAuthentication<HttpBearerAuth>('user_key').setAccessToken('YOUR_ACCESS_TOKEN');
// Case 2. Use Function which generate token.
// String yourTokenGeneratorFunction() { ... }
//defaultApiClient.getAuthentication<HttpBearerAuth>('user_key').setAccessToken(yourTokenGeneratorFunction);

final api_instance = DefaultApi();
final appId = appId_example; // String | An app id

try {
    final result = api_instance.getApp(appId);
    print(result);
} catch (e) {
    print('Exception when calling DefaultApi->getApp: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **appId** | **String**| An app id | 

### Return type

[**App**](App.md)

### Authorization

[user_key](../README.md#user_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getApps**
> List<App> getApps()

View apps

View the details of all of your current OneSignal apps

### Example
```dart
import 'package:openapi/api.dart';
// TODO Configure HTTP Bearer authorization: user_key
// Case 1. Use String Token
//defaultApiClient.getAuthentication<HttpBearerAuth>('user_key').setAccessToken('YOUR_ACCESS_TOKEN');
// Case 2. Use Function which generate token.
// String yourTokenGeneratorFunction() { ... }
//defaultApiClient.getAuthentication<HttpBearerAuth>('user_key').setAccessToken(yourTokenGeneratorFunction);

final api_instance = DefaultApi();

try {
    final result = api_instance.getApps();
    print(result);
} catch (e) {
    print('Exception when calling DefaultApi->getApps: $e\n');
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**List<App>**](App.md)

### Authorization

[user_key](../README.md#user_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getNotification**
> NotificationWithMeta getNotification(appId, notificationId)

View notification

View the details of a single notification and outcomes associated with it

### Example
```dart
import 'package:openapi/api.dart';
// TODO Configure HTTP Bearer authorization: app_key
// Case 1. Use String Token
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken('YOUR_ACCESS_TOKEN');
// Case 2. Use Function which generate token.
// String yourTokenGeneratorFunction() { ... }
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken(yourTokenGeneratorFunction);

final api_instance = DefaultApi();
final appId = appId_example; // String | 
final notificationId = notificationId_example; // String | 

try {
    final result = api_instance.getNotification(appId, notificationId);
    print(result);
} catch (e) {
    print('Exception when calling DefaultApi->getNotification: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **appId** | **String**|  | 
 **notificationId** | **String**|  | 

### Return type

[**NotificationWithMeta**](NotificationWithMeta.md)

### Authorization

[app_key](../README.md#app_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getNotificationHistory**
> NotificationHistorySuccessResponse getNotificationHistory(notificationId, getNotificationRequestBody)

Notification History

-> View the devices sent a message - OneSignal Paid Plan Required This method will return all devices that were sent the given notification_id of an Email or Push Notification if used within 7 days of the date sent. After 7 days of the sending date, the message history data will be unavailable. After a successful response is received, the destination url may be polled until the file becomes available. Most exports are done in ~1-3 minutes, so setting a poll interval of 10 seconds should be adequate. For use cases that are not meant to be consumed by a script, an email will be sent to the supplied email address. &#x1F6A7; Requirements A OneSignal Paid Plan. Turn on Send History via OneSignal API in Settings -> Analytics. Cannot get data before this was turned on. Must be called within 7 days after sending the message. Messages targeting under 1000 recipients will not have \"sent\" events recorded, but will show \"clicked\" events. Requires your OneSignal App's REST API Key, available in Keys & IDs.

### Example
```dart
import 'package:openapi/api.dart';
// TODO Configure HTTP Bearer authorization: app_key
// Case 1. Use String Token
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken('YOUR_ACCESS_TOKEN');
// Case 2. Use Function which generate token.
// String yourTokenGeneratorFunction() { ... }
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken(yourTokenGeneratorFunction);

final api_instance = DefaultApi();
final notificationId = notificationId_example; // String | The \"id\" of the message found in the Notification object
final getNotificationRequestBody = GetNotificationRequestBody(); // GetNotificationRequestBody | 

try {
    final result = api_instance.getNotificationHistory(notificationId, getNotificationRequestBody);
    print(result);
} catch (e) {
    print('Exception when calling DefaultApi->getNotificationHistory: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **notificationId** | **String**| The \"id\" of the message found in the Notification object | 
 **getNotificationRequestBody** | [**GetNotificationRequestBody**](GetNotificationRequestBody.md)|  | 

### Return type

[**NotificationHistorySuccessResponse**](NotificationHistorySuccessResponse.md)

### Authorization

[app_key](../README.md#app_key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getNotifications**
> NotificationSlice getNotifications(appId, limit, offset, kind)

View notifications

View the details of multiple notifications

### Example
```dart
import 'package:openapi/api.dart';
// TODO Configure HTTP Bearer authorization: app_key
// Case 1. Use String Token
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken('YOUR_ACCESS_TOKEN');
// Case 2. Use Function which generate token.
// String yourTokenGeneratorFunction() { ... }
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken(yourTokenGeneratorFunction);

final api_instance = DefaultApi();
final appId = appId_example; // String | The app ID that you want to view notifications from
final limit = 56; // int | How many notifications to return.  Max is 50.  Default is 50.
final offset = 56; // int | Page offset.  Default is 0.  Results are sorted by queued_at in descending order.  queued_at is a representation of the time that the notification was queued at.
final kind = 56; // int | Kind of notifications returned:   * unset - All notification types (default)   * `0` - Dashboard only   * `1` - API only   * `3` - Automated only 

try {
    final result = api_instance.getNotifications(appId, limit, offset, kind);
    print(result);
} catch (e) {
    print('Exception when calling DefaultApi->getNotifications: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **appId** | **String**| The app ID that you want to view notifications from | 
 **limit** | **int**| How many notifications to return.  Max is 50.  Default is 50. | [optional] 
 **offset** | **int**| Page offset.  Default is 0.  Results are sorted by queued_at in descending order.  queued_at is a representation of the time that the notification was queued at. | [optional] 
 **kind** | **int**| Kind of notifications returned:   * unset - All notification types (default)   * `0` - Dashboard only   * `1` - API only   * `3` - Automated only  | [optional] 

### Return type

[**NotificationSlice**](NotificationSlice.md)

### Authorization

[app_key](../README.md#app_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getOutcomes**
> OutcomesData getOutcomes(appId, outcomeNames, outcomeNamesLeftSquareBracketRightSquareBracket, outcomeTimeRange, outcomePlatforms, outcomeAttribution)

View Outcomes

View the details of all the outcomes associated with your app  &#x1F6A7; Requires Authentication Key Requires your OneSignal App's REST API Key, available in Keys & IDs.  &#x1F6A7; Outcome Data Limitations Outcomes are only accessible for around 30 days before deleted from our servers. You will need to export this data every month if you want to keep it. 

### Example
```dart
import 'package:openapi/api.dart';
// TODO Configure HTTP Bearer authorization: app_key
// Case 1. Use String Token
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken('YOUR_ACCESS_TOKEN');
// Case 2. Use Function which generate token.
// String yourTokenGeneratorFunction() { ... }
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken(yourTokenGeneratorFunction);

final api_instance = DefaultApi();
final appId = appId_example; // String | The OneSignal App ID for your app.  Available in Keys & IDs.
final outcomeNames = outcomeNames_example; // String | Required Comma-separated list of names and the value (sum/count) for the returned outcome data. Note: Clicks only support count aggregation. For out-of-the-box OneSignal outcomes such as click and session duration, please use the \"os\" prefix with two underscores. For other outcomes, please use the name specified by the user. Example:os__session_duration.count,os__click.count,CustomOutcomeName.sum 
final outcomeNamesLeftSquareBracketRightSquareBracket = outcomeNamesLeftSquareBracketRightSquareBracket_example; // String | Optional If outcome names contain any commas, then please specify only one value at a time. Example: outcome_names[]=os__click.count&outcome_names[]=Sales, Purchase.count where \"Sales, Purchase\" is the custom outcomes with a comma in the name. 
final outcomeTimeRange = outcomeTimeRange_example; // String | Optional Time range for the returned data. The values can be 1h (for the last 1 hour data), 1d (for the last 1 day data), or 1mo (for the last 1 month data). Default is 1h if the parameter is omitted. 
final outcomePlatforms = outcomePlatforms_example; // String | Optional Platform id. Refer device's platform ids for values. Example: outcome_platform=0 for iOS outcome_platform=7,8 for Safari and Firefox Default is data from all platforms if the parameter is omitted. 
final outcomeAttribution = outcomeAttribution_example; // String | Optional Attribution type for the outcomes. The values can be direct or influenced or unattributed. Example: outcome_attribution=direct Default is total (returns direct+influenced+unattributed) if the parameter is omitted. 

try {
    final result = api_instance.getOutcomes(appId, outcomeNames, outcomeNamesLeftSquareBracketRightSquareBracket, outcomeTimeRange, outcomePlatforms, outcomeAttribution);
    print(result);
} catch (e) {
    print('Exception when calling DefaultApi->getOutcomes: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **appId** | **String**| The OneSignal App ID for your app.  Available in Keys & IDs. | 
 **outcomeNames** | **String**| Required Comma-separated list of names and the value (sum/count) for the returned outcome data. Note: Clicks only support count aggregation. For out-of-the-box OneSignal outcomes such as click and session duration, please use the \"os\" prefix with two underscores. For other outcomes, please use the name specified by the user. Example:os__session_duration.count,os__click.count,CustomOutcomeName.sum  | 
 **outcomeNamesLeftSquareBracketRightSquareBracket** | **String**| Optional If outcome names contain any commas, then please specify only one value at a time. Example: outcome_names[]=os__click.count&outcome_names[]=Sales, Purchase.count where \"Sales, Purchase\" is the custom outcomes with a comma in the name.  | [optional] 
 **outcomeTimeRange** | **String**| Optional Time range for the returned data. The values can be 1h (for the last 1 hour data), 1d (for the last 1 day data), or 1mo (for the last 1 month data). Default is 1h if the parameter is omitted.  | [optional] 
 **outcomePlatforms** | **String**| Optional Platform id. Refer device's platform ids for values. Example: outcome_platform=0 for iOS outcome_platform=7,8 for Safari and Firefox Default is data from all platforms if the parameter is omitted.  | [optional] 
 **outcomeAttribution** | **String**| Optional Attribution type for the outcomes. The values can be direct or influenced or unattributed. Example: outcome_attribution=direct Default is total (returns direct+influenced+unattributed) if the parameter is omitted.  | [optional] 

### Return type

[**OutcomesData**](OutcomesData.md)

### Authorization

[app_key](../README.md#app_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getPlayer**
> Player getPlayer(appId, playerId, emailAuthHash)

View device

View the details of an existing device in one of your OneSignal apps

### Example
```dart
import 'package:openapi/api.dart';
// TODO Configure HTTP Bearer authorization: app_key
// Case 1. Use String Token
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken('YOUR_ACCESS_TOKEN');
// Case 2. Use Function which generate token.
// String yourTokenGeneratorFunction() { ... }
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken(yourTokenGeneratorFunction);

final api_instance = DefaultApi();
final appId = appId_example; // String | Your app_id for this device
final playerId = playerId_example; // String | Player's OneSignal ID
final emailAuthHash = emailAuthHash_example; // String | Email - Only required if you have enabled Identity Verification and device_type is email (11).

try {
    final result = api_instance.getPlayer(appId, playerId, emailAuthHash);
    print(result);
} catch (e) {
    print('Exception when calling DefaultApi->getPlayer: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **appId** | **String**| Your app_id for this device | 
 **playerId** | **String**| Player's OneSignal ID | 
 **emailAuthHash** | **String**| Email - Only required if you have enabled Identity Verification and device_type is email (11). | [optional] 

### Return type

[**Player**](Player.md)

### Authorization

[app_key](../README.md#app_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getPlayers**
> PlayerSlice getPlayers(appId, limit, offset)

View devices

View the details of multiple devices in one of your OneSignal apps Unavailable for Apps Over 80,000 Users For performance reasons, this method is not available for larger apps. Larger apps should use the CSV export API endpoint, which is much more performant. 

### Example
```dart
import 'package:openapi/api.dart';
// TODO Configure HTTP Bearer authorization: app_key
// Case 1. Use String Token
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken('YOUR_ACCESS_TOKEN');
// Case 2. Use Function which generate token.
// String yourTokenGeneratorFunction() { ... }
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken(yourTokenGeneratorFunction);

final api_instance = DefaultApi();
final appId = appId_example; // String | The app ID that you want to view players from
final limit = 56; // int | How many devices to return. Max is 300. Default is 300
final offset = 56; // int | Result offset. Default is 0. Results are sorted by id;

try {
    final result = api_instance.getPlayers(appId, limit, offset);
    print(result);
} catch (e) {
    print('Exception when calling DefaultApi->getPlayers: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **appId** | **String**| The app ID that you want to view players from | 
 **limit** | **int**| How many devices to return. Max is 300. Default is 300 | [optional] 
 **offset** | **int**| Result offset. Default is 0. Results are sorted by id; | [optional] 

### Return type

[**PlayerSlice**](PlayerSlice.md)

### Authorization

[app_key](../README.md#app_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateApp**
> App updateApp(appId, app)

Update an app

Updates the name or configuration settings of an existing OneSignal app

### Example
```dart
import 'package:openapi/api.dart';
// TODO Configure HTTP Bearer authorization: user_key
// Case 1. Use String Token
//defaultApiClient.getAuthentication<HttpBearerAuth>('user_key').setAccessToken('YOUR_ACCESS_TOKEN');
// Case 2. Use Function which generate token.
// String yourTokenGeneratorFunction() { ... }
//defaultApiClient.getAuthentication<HttpBearerAuth>('user_key').setAccessToken(yourTokenGeneratorFunction);

final api_instance = DefaultApi();
final appId = appId_example; // String | An app id
final app = App(); // App | 

try {
    final result = api_instance.updateApp(appId, app);
    print(result);
} catch (e) {
    print('Exception when calling DefaultApi->updateApp: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **appId** | **String**| An app id | 
 **app** | [**App**](App.md)|  | 

### Return type

[**App**](App.md)

### Authorization

[user_key](../README.md#user_key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updatePlayer**
> UpdatePlayerSuccessResponse updatePlayer(playerId, player)

Edit device

Update an existing device in one of your OneSignal apps

### Example
```dart
import 'package:openapi/api.dart';
// TODO Configure HTTP Bearer authorization: app_key
// Case 1. Use String Token
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken('YOUR_ACCESS_TOKEN');
// Case 2. Use Function which generate token.
// String yourTokenGeneratorFunction() { ... }
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken(yourTokenGeneratorFunction);

final api_instance = DefaultApi();
final playerId = playerId_example; // String | Player's OneSignal ID
final player = Player(); // Player | 

try {
    final result = api_instance.updatePlayer(playerId, player);
    print(result);
} catch (e) {
    print('Exception when calling DefaultApi->updatePlayer: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **playerId** | **String**| Player's OneSignal ID | 
 **player** | [**Player**](Player.md)|  | 

### Return type

[**UpdatePlayerSuccessResponse**](UpdatePlayerSuccessResponse.md)

### Authorization

[app_key](../README.md#app_key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updatePlayerTags**
> UpdatePlayerTagsSuccessResponse updatePlayerTags(appId, externalUserId, updatePlayerTagsRequestBody)

Edit tags with external user id

Update an existing device's tags in one of your OneSignal apps using the External User ID. Warning - Android SDK Data Synchronization Tags added through the Android SDK tagging methods may not update if using the API to change or update the same tag. For example, if you use SDK method sendTag(\"key\", \"value1\") then update the tag value to \"value2\" with this API endpoint. You will not be able to set the value back to \"value1\" through the SDK, you will need to change it to something different through the SDK to be reset. Recommendations if using this Endpoint on Android Mobile Apps: 1 - Do not use the same tag keys for SDK and API updates 2 - If you want to use the same key for both SDK and API updates, call the SDK getTags method first to update the device's tags. This is only applicable on the Android Mobile App SDKs. &#128216; Deleting Tags To delete a tag, include its key and set its value to blank. Omitting a key/value will not delete it. For example, if I wanted to delete two existing tags rank and category while simultaneously adding a new tag class, the tags JSON would look like the following: \"tags\": {    \"rank\": \"\",    \"category\": \"\",    \"class\": \"my_new_value\" } 

### Example
```dart
import 'package:openapi/api.dart';
// TODO Configure HTTP Bearer authorization: app_key
// Case 1. Use String Token
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken('YOUR_ACCESS_TOKEN');
// Case 2. Use Function which generate token.
// String yourTokenGeneratorFunction() { ... }
//defaultApiClient.getAuthentication<HttpBearerAuth>('app_key').setAccessToken(yourTokenGeneratorFunction);

final api_instance = DefaultApi();
final appId = appId_example; // String | The OneSignal App ID the user record is found under.
final externalUserId = externalUserId_example; // String | The External User ID mapped to teh device record in OneSignal.  Must be actively set on the device to be updated.
final updatePlayerTagsRequestBody = UpdatePlayerTagsRequestBody(); // UpdatePlayerTagsRequestBody | 

try {
    final result = api_instance.updatePlayerTags(appId, externalUserId, updatePlayerTagsRequestBody);
    print(result);
} catch (e) {
    print('Exception when calling DefaultApi->updatePlayerTags: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **appId** | **String**| The OneSignal App ID the user record is found under. | 
 **externalUserId** | **String**| The External User ID mapped to teh device record in OneSignal.  Must be actively set on the device to be updated. | 
 **updatePlayerTagsRequestBody** | [**UpdatePlayerTagsRequestBody**](UpdatePlayerTagsRequestBody.md)|  | [optional] 

### Return type

[**UpdatePlayerTagsSuccessResponse**](UpdatePlayerTagsSuccessResponse.md)

### Authorization

[app_key](../README.md#app_key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

